library(tidyverse)
library(cowplot)
library(scales)

# global figure settings
source(file="predict_wrapper.R")
source(file="plotting.R")
source(file="settings.R")

###########################################################
###################### CONSTANTS ##########################
###########################################################

# prediction constants
method="pls"
Nrep = 1024
Ncore = 4
remove_dups = F

# figure constants
clust_method = "complete"

FIG_SI_PATH = "figures/si/"

DATATYPES = c("rppa", "rnaseq")
SENS = c("ccle", "ctrp")

drugs <- c('Cobimetinib', 'Irinotecan',  'Dabrafenib', 'DM1', 'Docetaxel', 'Doxorubicin', 'Apo2L', 'Apo2L+FlagM2', 'BRD6929', 'G02594618', 'G02594618+NA', 'AR00482666', 'Taselisib', 'GDC0575', 'GDC0994', 'Gemcitabine', 'GNE330', 'MMAE', 'Oligomycin', 'Paclitaxel', 'PD901', 'PNU159682', 'SG2507', 'SN34994', 'Trametinib', 'TrichostatinA', 'Vemurafenib')
drugs_gdc0068 = c("GDC0068", drugs)
drugtargets_simple <- c('MAPK', 'Chemo',  'MAPK', 'Chemo', 'Chemo', 'Chemo', 'Other', 'Other', 'HDAC', 'Other', 'Other', 'MAPK', 'PI3K', 'CHK1', 'MAPK', 'Chemo', 'CHK1', 'Chemo', 'Other', 'Chemo', 'MAPK', 'Chemo', 'Chemo', 'Chemo', 'MAPK', 'HDAC', 'MAPK')
drugtargets_simple_gdc0068 = c("AKT", drugtargets_simple)
drugtargets_simple <- ordered(drugtargets_simple,levels=c("MAPK","PI3K","Chemo","HDAC","CHK1","Other"))
drugtargets_simple_gdc0068 = ordered(drugtargets_simple_gdc0068, levels=c("AKT", "MAPK","PI3K","Chemo","HDAC","CHK1","Other"))


Nph_res = 200
ph_annotation_drug <- data.frame(Drugtype = drugtargets_simple)
ph_annotation_drug_color <- c("coral1","cadetblue3","chartreuse3","deepskyblue2","goldenrod3","darkorchid2")
names(ph_annotation_drug_color) <- c("MAPK","PI3K","Chemo","HDAC","CHK1","Other")
rownames(ph_annotation_drug) <- drugs
ph_annotation_drug_color_list <- list(Drugtype = ph_annotation_drug_color)

###########################################################
#################### HELPER FUNCTIONS #####################
###########################################################
# helper function
LoadToEnvironment <- function(RData, env = new.env()){
  load(RData, env)
  return(env) 
}

R2 = function(meas,preds) {
  notNA = !is.na(meas) & !is.na(preds)
  meas = meas[notNA]
  preds = preds[notNA]
  return(1-sum((meas-preds)^2)/sum((meas-mean(meas))^2))
}

str_wrap_factor <- function(x, ...) {
  levels(x) <- str_wrap(levels(x), ...)
  return(x)
}

filename_data2SIFig = function(s) {
  name = str_match(s,"(\\w+)\\.\\w+$")[2]
  return(paste(FIG_SI_PATH,name,".pdf", sep=""))
}


# plot predictions
plot_pred = function(meas, preds, predplot=T, drug_show=T) {
  muts = getData(list(datasource='gt', datatype="mut", version="signature"))
  drug = colnames(meas)[1]
  
  mutfn = function(df) {
    braf = df$BRAF
    nras = df$NRAS
    notNA = !is.na(braf)
    ret = rep("Other", length(braf))
    ret[notNA][which(braf[notNA]==1)] = "BRAF V600E/K"
    ret[notNA][which(nras[notNA]==1)] = "NRAS"
    return(ret)
  }
  
  df = data.frame(meas=meas[,1,drop=F], preds=preds[,1,drop=F])
  colnames(df) = c("meas", "preds")
  df = left_join(df %>% mutate(CL=rownames(df)), muts %>% mutate(CL=rownames(muts)), by="CL") %>% 
    select(-KRAS,-BRAFother) %>% 
    mutate(Mutation=mutfn(.)) %>% 
    select(-BRAF,-NRAS)
  rownames(df) = df$CL
  df$CL = NULL
  
  df$Mutation = ordered(df$Mutation, levels=c("BRAF V600E/K", "NRAS", "Other"))
  
  if(predplot) {
    #R2lab = paste("R^2 == '", sprintf('%.2f',R2(meas, preds)),"'",sep="")
    rholab = paste("rho == '", sprintf('%.2f',cor(meas, preds, use="complete.obs")),"'",sep="")
    #R2lab = paste("R^2 == ",sprintf('%.2f',round(0.40,2)),sep="")
  } else {
    #R2lab = paste("r^2 == '", sprintf('%.2f',cor(meas, preds, use="complete.obs")^2),"'",sep="")
    rholab = paste("rho == '", sprintf('%.2f',cor(meas, preds, use="complete.obs")),"'",sep="")
  }
  
  minX <- min(meas,na.rm=TRUE)
  maxX <- max(meas,na.rm=TRUE)
  minY <- min(preds,na.rm=TRUE)
  maxY <- max(preds,na.rm=TRUE)
  if(max(preds, na.rm=T)/min(preds, na.rm=T)<1.1) {
    minY <- mean(preds,na.rm=TRUE)-0.6*(max(meas, na.rm=T)-min(meas, na.rm=T))
    maxY <- mean(preds,na.rm=TRUE)+0.4*(max(meas, na.rm=T)-min(meas, na.rm=T))
  }
  
  xlab = ifelse(predplot, "Measured AUC", paste(colnames(meas)[1], "AUC", sep=" "))
  ylab = ifelse(predplot, "Predicted AUC", paste(colnames(preds)[1], "AUC", sep=" "))
  
  ggpred = ggplot(df, aes(x=meas, y=preds)) +
    geom_point(aes(color=Mutation, shape=Mutation)) +
    xlab(xlab) +
    ylab(ylab) +
    theme(axis.title = element_text(size=size_axes_title),
          axis.text = element_text(size=size_axes_text), 
          legend.title = element_blank(),
          legend.text = element_text(size=size_axes_text),
          legend.key.size = unit(size_axes_text, "points"),
          #plot.margin = unit(c(0,0,0,0), "cm"),
          panel.background = element_rect(colour = "black", fill=NA, size=1, linetype="solid"))+
    scale_shape_manual(values=c("BRAF V600E/K"=16,"NRAS"=17,"Other"=15))+
    scale_color_manual(values=c("BRAF V600E/K"=colors()[29],"NRAS"=colors()[34],"Other"="green4"))+
    coord_cartesian(xlim=c(minX, maxX), ylim=c(minY,maxY))+
    annotate("text", x=minX+0.2*(maxX-minX),y=minY+0.9*(maxY-minY), label=rholab, parse=T, size=2.5)
  
  if(drug_show)
    ggpred = ggpred + 
    annotate("text", x=minX+0.7*(maxX-minX),y=minY+0.04*(maxY-minY), label=drug, size=2.5)
  
  #save_plot(filename="tmp.pdf", ggpred+theme(legend.position = "none"), base_width = 2, base_height = 2)
  
  return(ggpred)
  
}

###########################################################
########## Melanoma Predicting AUC from BRAFV600E #########
###########################################################

braf = getData(list(datasource="gt", datatype="mut", version="signature"), match_CLs=list(datasource="gt", datatype="sen", tissue="skin"), remove_dups=remove_dups)[,"BRAF", drop=F]
braf$BRAF = ifelse(braf$BRAF==1, "V600E/K", "Other")
auc = getData(list(datasource="gt", datatype="sen", tissue="skin"), match_CLs=list(datasource="gt", datatype="mut", version="signature"), remove_dups=remove_dups)
drug_target = getDrugTarget(list(datasource="gt", datatype="sen", tissue="skin"))
drug_lab = drug_type_label(drug_target$drug_targets)
#drug_target = data.frame(drug=drug_target$drugs, drug_target=drug_target$drug_targets)

df = data.frame(Cell.Line=rownames(auc), braf=braf, auc, check.names = F)

df = df %>% 
  gather("drug", "auc", -c("Cell.Line", "BRAF"))

df = left_join(df, 
               data.frame(drug=drug_target$drugs, drug_target=drug_lab$drug_targets), 
               by="drug" )

df$BRAF = ordered(df$BRAF, level=c("V600E/K", "Other"))
df$drug = ordered(df$drug, levels=drug_target$drugs[order(drug_lab$drug_targets)])

df %>% 
  as_data_frame %>% 
  mutate(drug=as.character(drug)) %>% 
  arrange(drug_target, drug) %>% 
  mutate(drug=factor(drug, levels=unique(drug), ordered=T)) -> df2

pvals = c()
for(drug in unique(df$drug)) {
  pvals = c(pvals, t.test(df[df$drug==drug & df$BRAF=="V600E/K","auc"], 
                          df[df$drug==drug & df$BRAF=="Other","auc"], na.action=na.omit)$p.value)
}
names(pvals) = unique(df$drug)
pvals_adj = p.adjust(pvals, method="BH")


gg = ggplot(df2, aes(x=drug, y=auc, color=BRAF))+
  stat_summary(fun.data = quantiles_90, geom="boxplot", position="dodge", lwd=0.4 )+
  annotate("segment", x=16.5, xend=17.5, y=120, yend=120)+
  annotate("text", x=17, y=120, label="***", size=3.2)+
  annotate("segment", x=20.5, xend=21.5, y=120, yend=120)+
  annotate("text", x=21, y=120, label="***", size=3.2)+
  #geom_point(size=0.2, position = position_jitterdodge(jitter.width=0.1))+
  geom_tile(aes(fill=drug_target, y=2, height=3), color="white", size=size_tile_border)+
  theme(axis.text.x = element_text(size=size_axes_text, angle=-90,  hjust=0, vjust=0.5),
        axis.title.y = element_text(size=size_axes_title),
        axis.text.y = element_text(size=size_axes_text),
        legend.title = element_text(size=size_legend),
        panel.background = element_rect(colour = "black", fill=NA, size=1, linetype="solid"),
        #legend.position = c(0.23, 0.19),
        legend.text = element_text(size=size_legend), # FIXME, MAKE LEGEND LOOK NICE
        legend.text.align = 0,
        axis.title.x = element_blank())+
  coord_cartesian(ylim=c(5,125))+
  scale_fill_manual(values=drug_lab$drug_target_color)+
  scale_color_manual(values=c("V600E/K"="red","Other"="blue"))+
  labs(fill="Drug target", color="")+
  ylab("AUC")

save_plot(filename=paste(FIG_SI_PATH,"via_braf.pdf", sep=""), gg, base_height = 5, base_width = 7)


#################################################################
###################   Melanoma mutation versions  ##############
#################################################################

out_mel_mut_specPt = read_analysis_data(expand.grid(datasource = "gt", datatype = "mut", version="specPt", tissue="skin", sen="gt", method="regressiontree", matched="FALSE", remove_dups=remove_dups, integration="early" ), return_outs = T)[[1]]
out_mel_mut_unspecPt = read_analysis_data(expand.grid(datasource = "gt", datatype = "mut", version="unspecPt", tissue="skin", sen="gt", method="regressiontree", matched="FALSE", remove_dups=remove_dups, integration="early" ), return_outs = T)[[1]]
out_mel_mut_gene = read_analysis_data(expand.grid(datasource = "gt", datatype = "mut", version="gene", tissue="skin", sen="gt", method="regressiontree", matched="FALSE", remove_dups=remove_dups, integration="early" ), return_outs = T)[[1]]
out_mel_mut_signature = read_analysis_data(expand.grid(datasource = "gt", datatype = "mut", version="signature", tissue="skin", sen="gt", method="regressiontree", matched="FALSE", remove_dups=remove_dups, integration="early" ), return_outs = T)[[1]]

out_list = list(out_mel_mut_specPt, out_mel_mut_unspecPt, out_mel_mut_gene, out_mel_mut_signature)
names(out_list) = c("Point mutation", "Any point mutation", "Gene mutation", "Signature mutation")

gg = plot_corsheatmap(out_list, labels=names(out_list), valVar="cors", plot_legend=T, line_break=F)

filename = paste(FIG_SI_PATH,"gg_mel_mut_ver.pdf", sep="")
save_plot(filename=filename, gg$fig, base_height = 6.3, base_width = get_plotcorsheatmap_width(out_list))



###########################################################
###### Predict AUC from individual RPPA signals #####
###########################################################

rppa = getData(list(datasource="gt", datatype="rppa", tissue="skin"), 
               match_CLs=list(datasource="gt", datatype="sen", tissue="skin"),
               remove_dups = remove_dups)
sen = getData(list(datasource="gt", datatype="sen", tissue="skin"), 
              match_CLs=list(datasource="gt", datatype="rppa", tissue="skin"),
              remove_dups = remove_dups)

drug_targets = getDrugTarget(list(datasource="gt", datatype="sen", tissue="skin"), 
                             match_CLs=list(datasource="gt", datatype="rppa", tissue="skin"))
drug_targets_lab = drug_type_label(drug_targets$drug_targets)

spearman <- matrix(NA, ncol=ncol(sen), nrow=ncol(rppa))
spearman_bg <- array(NA, dim=c(ncol(rppa), ncol(sen), Nrep), dimnames=list(colnames(rppa), colnames(sen), 1:Nrep))
spearman_pval <- matrix(NA, ncol=ncol(sen), nrow=ncol(rppa))
colnames(spearman) = colnames(sen)
rownames(spearman) = colnames(rppa)
colnames(spearman_pval) = colnames(sen)
rownames(spearman_pval) = colnames(rppa)

# compute correlation between drug/protein
for(prot in colnames(rppa)) {
  for(drug in colnames(sen)) {
    spearman[prot, drug] = cor(rppa[,prot], sen[,drug], method = "spearman", use="complete.obs")
  }
}

# compute correlation between drug/protein - RANDOM SHUFFLE
cluster <- makeCluster(Ncore, type="FORK")
spearman_bg_list = parLapply(cluster,seq(1,Nrep),function(x) { 
  spearman_bg_tmp <- matrix(NA, ncol=ncol(sen), nrow=ncol(rppa))
  colnames(spearman_bg_tmp) = colnames(sen)
  rownames(spearman_bg_tmp) = colnames(rppa)
    for(prot in colnames(rppa)) {
      for(drug in colnames(sen)) {
        spearman_bg_tmp[prot, drug] = cor(rppa[,prot], sample(sen[,drug]), method = "spearman", use="complete.obs")
      }
    }
  return(spearman_bg_tmp)
} )
stopCluster(cluster)
spearman_bg = simplify2array(spearman_bg_list)

# compute p-vals
for(prot in colnames(rppa)) {
  for(drug in colnames(sen)) {
    spearman_pval[prot, drug] = (1+length(which(abs(spearman_bg[prot, drug,])>abs(spearman[prot,drug]))))/length(spearman_bg[prot,drug,])
  }
}


spearman_pval_adj = data.frame(matrix(p.adjust(as.vector(as.matrix(spearman_pval)),method="BH"),ncol=ncol(spearman_pval)))
colnames(spearman_pval_adj) = colnames(sen)
rownames(spearman_pval_adj) = colnames(rppa)
spearman_pval_log = -log10(spearman_pval)
spearman_pval_adj_log = -log10(spearman_pval_adj)

gg_ViaRppaCor = plot_drugX_heatmap(spearman, drug_targets = drug_targets, gradient = "cors")
save_plot(filename=paste(FIG_SI_PATH,"gg_ViaRppaCor.pdf", sep=""), gg_ViaRppaCor, base_height = 7, base_width = 5)

gg_ViaRppaCor_pvaladj = plot_drugX_heatmap(spearman_pval_adj_log, drug_targets = drug_targets, gradient = "log10Padj")
save_plot(filename=paste(FIG_SI_PATH,"gg_ViaRppaCor_pvaladj.pdf", sep=""), gg_ViaRppaCor_pvaladj, base_height = 6.3, base_width = 5)

gg_ViaRppaCor_pval = plot_drugX_heatmap(-log10(spearman_pval), drug_targets = drug_targets, gradient = "log10P")
save_plot(filename=paste(FIG_SI_PATH,"gg_ViaRppaCor_pval.pdf", sep=""), gg_ViaRppaCor_pval, base_height = 7, base_width = 5)



###########################################################
############# Melanoma compare methods ####################
###########################################################

out_gt_rppa_pls = read_analysis_data(expand.grid(datasource = "gt", datatype = "rppa", version="-", tissue="skin", sen="gt", method="pls", matched="FALSE", remove_dups=remove_dups, integration="early" ), return_outs = T)[[1]]
out_gt_rppa_plsmulti = read_analysis_data(expand.grid(datasource = "gt", datatype = "rppa", version="-", tissue="skin", sen="gt", method="plsmulti", matched="FALSE", remove_dups=remove_dups, integration="early" ), return_outs = T)[[1]]
out_gt_rppa_regressiontree = read_analysis_data(expand.grid(datasource = "gt", datatype = "rppa", version="-", tissue="skin", sen="gt", method="regressiontree", matched="FALSE", remove_dups=remove_dups, integration="early" ), return_outs = T)[[1]]
out_gt_rppa_lasso = read_analysis_data(expand.grid(datasource = "gt", datatype = "rppa", version="-", tissue="skin", sen="gt", method="lasso", matched="FALSE", remove_dups=remove_dups, integration="early" ), return_outs = T)[[1]]
out_gt_rppa_elasticnet =  read_analysis_data(expand.grid(datasource = "gt", datatype = "rppa", version="-", tissue="skin", sen="gt", method="elasticnet", matched="FALSE", remove_dups=remove_dups, integration="early" ), return_outs = T)[[1]]
out_gt_rppa_maxcor =  read_analysis_data(expand.grid(datasource = "gt", datatype = "rppa", version="-", tissue="skin", sen="gt", method="maxcor", matched="FALSE", remove_dups=remove_dups, integration="early" ), return_outs = T)[[1]]

out_gt_rnaseq_pls = read_analysis_data(expand.grid(datasource = "gt", datatype = "rnaseq", version="-", tissue="skin", sen="gt", method="pls", matched="FALSE", remove_dups=remove_dups, integration="early" ), return_outs = T)[[1]]
out_gt_rnaseq_plsmulti = read_analysis_data(expand.grid(datasource = "gt", datatype = "rnaseq", version="-", tissue="skin", sen="gt", method="plsmulti", matched="FALSE", remove_dups=remove_dups, integration="early" ), return_outs = T)[[1]]
out_gt_rnaseq_regressiontree = read_analysis_data(expand.grid(datasource = "gt", datatype = "rnaseq", version="-", tissue="skin", sen="gt", method="regressiontree", matched="FALSE", remove_dups=remove_dups, integration="early" ), return_outs = T)[[1]]
out_gt_rnaseq_lasso = read_analysis_data(expand.grid(datasource = "gt", datatype = "rnaseq", version="-", tissue="skin", sen="gt", method="lasso", matched="FALSE", remove_dups=remove_dups, integration="early" ), return_outs = T)[[1]]
out_gt_rnaseq_elasticnet = read_analysis_data(expand.grid(datasource = "gt", datatype = "rnaseq", version="-", tissue="skin", sen="gt", method="elasticnet", matched="FALSE", remove_dups=remove_dups, integration="early" ), return_outs = T)[[1]]
out_gt_rnaseq_maxcor = read_analysis_data(expand.grid(datasource = "gt", datatype = "rnaseq", version="-", tissue="skin", sen="gt", method="maxcor", matched="FALSE", remove_dups=remove_dups, integration="early" ), return_outs = T)[[1]]

outlist_rppa = list(out_gt_rppa_pls, out_gt_rppa_plsmulti, out_gt_rppa_regressiontree, out_gt_rppa_lasso, out_gt_rppa_elasticnet, out_gt_rppa_maxcor)
gg_gt_rppa_cors = plot_corsheatmap(outlist_rppa, labels=c("PLS", "PLS (multi)", "Regression tree", "Lasso", "Elasticnet", "Maxcor"), valVar="cors", plot_legend=T)
save_plot(filename=paste(FIG_SI_PATH,"gg_gt_rppa_mtd_cors.pdf", sep=""), gg_gt_rppa_cors$fig, base_height = 6.3, base_width = 4)
gg_gt_rppa_pvals = plot_corsheatmap(outlist_rppa, labels=c("PLS", "PLS (multi)", "Regression tree", "Lasso", "Elasticnet", "Maxcor"), valVar="pvals_cors", plot_legend=T)
save_plot(filename=paste(FIG_SI_PATH,"gg_gt_rppa_mtd_pvals.pdf", sep=""), gg_gt_rppa_pvals$fig, base_height = 6.3, base_width = 4)
gg_gt_rppa_pvals_adj = plot_corsheatmap(outlist_rppa, labels=c("PLS", "PLS (multi)", "Regression tree", "Lasso", "Elasticnet", "Maxcor"), valVar="pvals_cors_adj", plot_legend=T)
save_plot(filename=paste(FIG_SI_PATH,"gg_gt_rppa_mtd_pvals_adj.pdf", sep=""), gg_gt_rppa_pvals_adj$fig, base_height = 6.3, base_width = 4)

outlist_rnaseq = list(out_gt_rnaseq_pls, out_gt_rnaseq_plsmulti, out_gt_rnaseq_regressiontree, out_gt_rnaseq_lasso, out_gt_rnaseq_elasticnet, out_gt_rnaseq_maxcor)
gg_gt_rnaseq_cors = plot_corsheatmap(outlist_rnaseq, labels=c("PLS", "PLS (multi)", "Regression tree", "Lasso", "Elasticnet", "Maxcor"), valVar="cors", plot_legend=T)
save_plot(filename=paste(FIG_SI_PATH,"gg_gt_rnaseq_mtd_cors.pdf", sep=""), gg_gt_rnaseq_cors$fig, base_height = 6.3, base_width = 4)
gg_gt_rnaseq_pvals = plot_corsheatmap(outlist_rnaseq, labels=c("PLS", "PLS (multi)", "Regression tree", "Lasso", "Elasticnet",  "Maxcor"), valVar="pvals_cors", plot_legend=T)
save_plot(filename=paste(FIG_SI_PATH,"gg_gt_rnaseq_mtd_pvals.pdf", sep=""), gg_gt_rnaseq_pvals$fig, base_height = 6.3, base_width = 4)
gg_gt_rnaseq_pvals_adj = plot_corsheatmap(outlist_rnaseq, labels=c("PLS", "PLS (multi)", "Regression tree", "Lasso", "Elasticnet", "Maxcor"), valVar="pvals_cors_adj", plot_legend=T)
save_plot(filename=paste(FIG_SI_PATH,"gg_gt_rnaseq_mtd_pvals_adj.pdf", sep=""), gg_gt_rnaseq_pvals_adj$fig, base_height = 6.3, base_width = 4)


###########################################################
############# Melanoma Lasso plots ########################
###########################################################

lasso_drugs = c("Dabrafenib", "Vemurafenib", "MMAE")

lasso_sen = getData(list(datasource="gt", datatype="sen", tissue="skin"), match_CLs=list(datasource="gt", datatype="rppa", tissue="skin"))
lasso_rppa = getData(list(datasource="gt", datatype="rppa", tissue="skin"), match_CLs=list(datasource="gt", datatype="sen", tissue="skin")) 

for(d in lasso_drugs) {
  y_meas <-lasso_sen[,d]
  notNA <- which((y_meas != -1) & !is.na(y_meas))
  y_meas <- y_meas[notNA]
  #y_meas <- sample(y_meas,length(y_meas),replace=FALSE) # SHUFFLE
  xData <- lasso_rppa[notNA,]
  xData <- scale(xData)
  
  lambda <- seq(from=10,to=2,by=-0.2)
  
  xData <- data.matrix(xData)
  y_meas <- data.matrix(y_meas)
  fit <- glmnet(xData,y_meas,lambda=lambda)
  fit.cv = cv.glmnet(xData, y_meas, alpha=1, nfolds=K, maxit = 10000)
  
  lassostr <- paste("plot_lasso_",d,".pdf",sep='')
  lassostr_err <- paste("plot_lasso_",d,"_err.pdf",sep='')
  
  pdf(file=paste(FIG_SI_PATH,lassostr, sep=""))
  par(mar=c(4.5,4.5,1,4))
  plot(fit,main=d)
  vnat=coef(fit)
  vnat=vnat[-1,ncol(vnat)] # remove the intercept, and get the coefficients at the end of the path
  vnat=vnat[vnat!=0]
  axis(4, at=vnat,line=-.5,label=names(vnat),las=1,tick=FALSE, cex.axis=0.5) 
  dev.off()
  
  pdf(file=paste(FIG_SI_PATH,lassostr_err, sep=""))
  plot(fit.cv)
  dev.off()
  
  
}


###################################################################
########   Melanoma RPPA vs RNAseq vs mut (fair) vs  ##############
########        Rppa+Rnaseq (early/late)        ###################
###################################################################

out_mel_mut = read_analysis_data(expand.grid(datasource = "gt", datatype = "mut", version="unspecPt", tissue="skin", sen="gt", method="regressiontree", matched="TRUE", remove_dups=remove_dups, integration="early" ), return_outs = T)[[1]]
out_mel_rppa = read_analysis_data(expand.grid(datasource = "gt", datatype = "rppa", version="-", tissue="skin", sen="gt", method="pls", matched="TRUE", remove_dups=remove_dups, integration="early" ), return_outs = T)[[1]]
out_mel_rnaseq = read_analysis_data(expand.grid(datasource = "gt", datatype = "rnaseq", version="-", tissue="skin", sen="gt", method="pls", matched="TRUE", remove_dups=remove_dups, integration="early" ), return_outs = T)[[1]]
out_mel_rnaseq_verrppaskin = read_analysis_data(expand.grid(datasource = "gt", datatype = "rnaseq", version="rppaskin", tissue="skin", sen="gt", method="pls", matched="TRUE", remove_dups=remove_dups, integration="early" ), return_outs = T)[[1]]
out_mel_rpparnaseq_early = read_analysis_data(expand.grid(datasource = "gt", datatype = "rpparnaseq", version="-", tissue="skin", sen="gt", method="pls", matched="TRUE", remove_dups=remove_dups, integration="early" ), return_outs = T)[[1]]
out_mel_rpparnaseq_late = read_analysis_data(expand.grid(datasource = "gt", datatype = "rpparnaseq", version="-", tissue="skin", sen="gt", method="pls", matched="TRUE", remove_dups=remove_dups, integration="late" ), return_outs = T)[[1]]

out_list = list(out_mel_mut, out_mel_rppa, out_mel_rnaseq, out_mel_rnaseq_verrppaskin, out_mel_rpparnaseq_early, out_mel_rpparnaseq_late)

gg = plot_corsheatmap(out_list, labels=c("Mutation", "Protein", "mRNA", "mRNA (match protein)", "Protein+mRNA (early)", "Protein+mRNA (late)"), valVar="cors", plot_legend=T, line_break=F)
gg_pvals = plot_corsheatmap(out_list, labels=c("Mutation", "Protein", "mRNA", "mRNA (match protein)", "Protein+mRNA (early)", "Protein+mRNA (late)"), valVar="pvals_cors", plot_legend=T, line_break=F)


filename = paste(FIG_SI_PATH,"gg_skin_datatype.pdf", sep="")
save_plot(filename=filename, gg$fig, base_height = 6.3, base_width = get_plotcorsheatmap_width(out_list))
filename = paste(FIG_SI_PATH,"gg_skin_datatype_pvals.pdf", sep="")
save_plot(filename=filename, gg_pvals$fig, base_height = 6.3, base_width = get_plotcorsheatmap_width(out_list))



#######################################################################
################## Compare RNAseq versions ############################
#######################################################################

compare_rnaseq = function(plot_title=F, ds, vers, tissue, sen, matched, method="pls", plot_legend=T, save_pdf=T) {
  
  out_list = list()
  vers_plot_i = c()
  for(ver_i in 1:length(vers)) {
    ver = vers[ver_i]
    out =  read_analysis_data(expand.grid(datasource = ds, datatype = "rnaseq", version=ver, tissue=tissue, sen=sen, method=method, matched=matched, remove_dups=remove_dups, integration="early" ), return_outs = T)
    if(length(out)==0) {
      print(paste("Missing data:", ds, tissue, sen, ver ))
    } else {
      out_list[[length(out_list)+1]] = out[[1]]
      vers_plot_i = c(vers_plot_i, ver_i)
    }
  }
  if(length(out_list)>5) {
    labels = vers[vers_plot_i]
    labels = gsub("speed1","speed:",labels)
    labels = gsub("^-$","filtered",labels, perl=T)
    labels = gsub("unfilt","unfiltered",labels)
    
    tissue_plottitle = gsub("haematopoieticandlymphoidtissue", "haematop.+lymph.tissue", tissue)
    tissue_plottitle = gsub("centralnervoussystem", "CNS", tissue_plottitle)
    
    rnaseq_ver_plot = plot_corsheatmap(out_list, labels=labels, valVar="cors", plot_legend=plot_legend)
    filename =  paste("rnaseq_ver_",ds,"_",tissue,"_",sen,"_",method, sep="")
    title = paste(ds,"-rnaseq tissue-",tissue_plottitle,"\n auc-",sen," ",method, sep="")
    fig = rnaseq_ver_plot$fig
    if(plot_title) {
      fig_title <- ggdraw() + draw_label(title, fontface='bold', size=10)
      fig = plot_grid(fig_title, fig, ncol=1, rel_heights = c(0.1,1))
    }
    filename = paste(FIG_SI_PATH,filename,".pdf", sep="")
    if(save_pdf)
      save_plot(filename=filename, fig, base_height = 6.3, base_width = get_plotcorsheatmap_width(out_list))
    return(fig)
  }
  return(NULL)
}

compare_rnaseq_ccle = function(sen) {
  if(sen=="ccle") {
    tissues = TISSUE_CCLE_CCLE_ALL
    ncols = 3
    rel_widths = c(0.3, 0.3, 0.48)
  } else if(sen=="ctrp") {
    tissues = TISSUE_CCLE_CTRP_ALL
    ncols = 4
    rel_widths = c(0.2, 0.2, 0.2, 0.4)
  } else {
    print("Wrong sensitivity type, needs to be either ccle or ctrp")
    return(NULL)
  }
  
  plotlist = list()
  for(tissuei in 1:length(tissues)) {
    tissue = tissues[tissuei]
    
    if(tissuei %% ncols == 0) {
      plot = compare_rnaseq(plot_title=T, "ccle", VERSIONS_RNASEQ_CCLE, tissue, sen, matched=T, plot_legend=T, save_pdf=F)
      plotlist[[length(plotlist)+1]] = plot
      plots =  plot_grid(plotlist=plotlist[1:ncols], ncol=ncols, rel_widths = rel_widths)
      save_plot(filename=paste(FIG_SI_PATH,"rnaseq_ver_",sen,"_",tissuei/ncols,".pdf", sep=""), plots, base_width = 11, base_height=7)
      plotlist=list()
    } else {
      plot = compare_rnaseq(plot_title=T, "ccle", VERSIONS_RNASEQ_CCLE, tissue, "ccle", matched=T, plot_legend=F, save_pdf=F)
      plotlist[[length(plotlist)+1]] = plot
    }
  }
}

compare_rnaseq(plot_title=F, ds="gt", vers=VERSIONS_RNASEQ_GT, tissue="skin", sen="gt", matched=T, method="pls", plot_legend=T)
#compare_rnaseq(plot_title=T, ds="gt", vers=VERSIONS_RNASEQ_GT, tissue="skin", sen="gt", matched=T, method="lasso")

compare_rnaseq_ccle(sen="ccle")
compare_rnaseq_ccle(sen="ctrp")

###########################################################
### CCLE sensitivity predictions for different tissues ####
###########################################################

matched = T

outlist = read_analysis_data(rbind(expand.grid(datasource = "ccle", datatype = DATATYPE_NOMUT, version="-", tissue=TISSUE_CCLE_ALL, sen=SEN_CCLE, method="pls", matched="TRUE", remove_dups=remove_dups, integration="early" ),
                                            expand.grid(datasource = "ccle", datatype = "mut", version="-", tissue=TISSUE_CCLE_ALL, sen=SEN_CCLE, method="regressiontree", matched="TRUE", remove_dups=remove_dups, integration="early" )), return_outs = T)
dataXYs = data.frame(t(sapply(outlist, function(x) list(datatype=x$dataX[[1]]$datatype, tissue=x$dataX[[1]]$tissue, sen=x$dataY$datasource))))
dataXYs = cbind(dataXYs,data.frame(ix=1:nrow(dataXYs)))
dataXYs$sen = as.character(dataXYs$sen)
dataXYs$datatype = as.character(dataXYs$datatype)
dataXYs$tissue = as.character(dataXYs$tissue)
dataXYs = data.frame(dataXYs)

plotlist = lapply(1:length(outlist), function(i) plot_predict(outlist[[i]], plot_title=T, p_pos="none")$gg_errorbar_cors +
                            ggtitle(paste(dataXYs[i,'datatype'],dataXYs[i,'tissue'],dataXYs[i,'sen'], sep="-")) +
                            theme(legend.position="bottom",plot.title = element_text(size = 7), axis.text.x = element_text(size = 5)))

ix_ctrp_all = dataXYs[dataXYs$datatype=="rppa" & dataXYs$tissue=="all" & dataXYs$sen=="ctrp", "ix" ]
leg = get_legend(plotlist[[ix_ctrp_all]])

plotlist = lapply(plotlist, function(p) p + theme(legend.position = "none"))

sorted_ix = dataXYs %>% 
  arrange(sen,tissue,datatype) %>% 
  dplyr::select(ix)
sorted_ix = data.frame(sorted_ix)
sorted_ix = sorted_ix[,1]

plotlist = plotlist[sorted_ix]
  
plot1 = plot_grid(plot_grid(plotlist=plotlist[1:6], ncol=3), leg,nrow=2, rel_heights = c(0.9, 0.1))
plot2 = plot_grid(plot_grid(plotlist=plotlist[7:12], ncol=3), leg,nrow=2, rel_heights = c(0.9, 0.1))
plot3 = plot_grid(plot_grid(plotlist=plotlist[13:18], ncol=3), leg,nrow=2, rel_heights = c(0.9, 0.1))
plot4 = plot_grid(plot_grid(plotlist=plotlist[19:24], ncol=3), leg,nrow=2, rel_heights = c(0.9, 0.1))
plot5 = plot_grid(plot_grid(plotlist=plotlist[25:30], ncol=3), leg,nrow=2, rel_heights = c(0.9, 0.1))
plot6 = plot_grid(plot_grid(plotlist=plotlist[31:36], ncol=3), leg,nrow=2, rel_heights = c(0.9, 0.1))
plot7 = plot_grid(plot_grid(plotlist=plotlist[37:42], ncol=3), leg,nrow=2, rel_heights = c(0.9, 0.1))
plot8 = plot_grid(plot_grid(plotlist=plotlist[43:48], ncol=3), leg,nrow=2, rel_heights = c(0.9, 0.1))
plot9 = plot_grid(plot_grid(plotlist=plotlist[49:51], ncol=3), leg,nrow=2, rel_heights = c(0.9, 0.1))

save_plot(filename=paste(FIG_SI_PATH,"gg_ccle_predicts_matched", matched, "_1.pdf", sep=""), plot1, units="cm", base_width = 25, base_height=17)
save_plot(filename=paste(FIG_SI_PATH,"gg_ccle_predicts_matched", matched, "_2.pdf", sep=""), plot2, units="cm", base_width = 25, base_height=17)
save_plot(filename=paste(FIG_SI_PATH,"gg_ccle_predicts_matched", matched, "_3.pdf", sep=""), plot3, units="cm", base_width = 25, base_height=17)
save_plot(filename=paste(FIG_SI_PATH,"gg_ccle_predicts_matched", matched, "_4.pdf", sep=""), plot4, units="cm", base_width = 25, base_height=17)
save_plot(filename=paste(FIG_SI_PATH,"gg_ccle_predicts_matched", matched, "_5.pdf", sep=""), plot5, units="cm", base_width = 25, base_height=17)
save_plot(filename=paste(FIG_SI_PATH,"gg_ccle_predicts_matched", matched, "_6.pdf", sep=""), plot6, units="cm", base_width = 25, base_height=17)
save_plot(filename=paste(FIG_SI_PATH,"gg_ccle_predicts_matched", matched, "_7.pdf", sep=""), plot7, units="cm", base_width = 25, base_height=17)
save_plot(filename=paste(FIG_SI_PATH,"gg_ccle_predicts_matched", matched, "_8.pdf", sep=""), plot8, units="cm", base_width = 25, base_height=17)
save_plot(filename=paste(FIG_SI_PATH,"gg_ccle_predicts_matched", matched, "_9.pdf", sep=""), plot9, units="cm", base_width = 25, base_height=10)


###########################################################
############## GT RNAseq coefficients table ###############
###########################################################

out = predict_wrapper(dataX=list(datasource="gt", datatype="rnaseq", tissue="skin"), dataY=list(datasource="gt", datatype="sen", tissue="skin"), method="pls", filt_settings = list(mean_filt=2, sd_filt=0.5), remove_dups = remove_dups, Nrep=1, Nbg=0, return_model = T)

predictive_drugs = names(which(out$cors>0.25))
# Find drugs that are predictive and that have non-zero coefficients
rnaseq_names = names(out$models$Cobimetinib$coefficients[,,1])
coefs = matrix(NA, ncol = length(predictive_drugs), nrow=length(rnaseq_names))
rownames(coefs) = rnaseq_names
colnames(coefs) = predictive_drugs

for(drug in predictive_drugs) {
  drug_ncomp = paste(drug,"_ncomp",sep="")
  ncomp = out$models[[paste(drug,"_ncomp",sep="")]]
  coefs[,drug] = out$models[[drug]]$coefficients[,,ncomp]
}

write.csv(coefs, file="gt_rnaseq_coefs.csv")


###########################################################
########## GT predict RPPA from RNAseq/Mut ################
###########################################################


loadenv = LoadToEnvironment("analysis/mrnaVSprot_cosmic.RData")
out_mrnaVSprot = loadenv$out
#loadenv = LoadToEnvironment("analysis/out_protVSmut_unspecPt.RData")
#out_protVSmut = loadenv$out

rppa=getData(list(datasource="gt", datatype="rppa", tissue="skin"), match_CLs=list(datasource="gt", datatype="sen", tissue="skin"))
rppa_x_sd = apply(rppa,2,sd)
gg_mrnaVSprot = plot_predict(out_mrnaVSprot, manual_cont_annotation=rppa_x_sd,  manual_cont_annotation_label="variance")$gg_errorbar_cors
#gg_protVSmut = plot_predict(out_protVSmut, manual_cont_annotation=rppa_x_sd,  manual_cont_annotation_label="variance")$gg_errorbar_cors

save_plot(filename=paste(FIG_SI_PATH,"gg_mrnaVSprot_cosmic.pdf", sep=""), gg_mrnaVSprot, base_height = 4.5, base_width = 8.5)
#save_plot(filename=paste(FIG_SI_PATH,"gg_protVSmut_unspecPt.pdf", sep=""), gg_protVSmut, base_height = 4.5, base_width = 8.5)
